]> granicus.if.org Git - vim/commitdiff
updated for version 7.2b-028 v7.2b.028
authorBram Moolenaar <Bram@vim.org>
Wed, 6 Aug 2008 12:37:44 +0000 (12:37 +0000)
committerBram Moolenaar <Bram@vim.org>
Wed, 6 Aug 2008 12:37:44 +0000 (12:37 +0000)
src/gui.c
src/version.c

index 8568d33ab402b661a3862cabbf3bdb5599b5a63b..426cea92a571de607d676d7e6e63587a2c3400db 100644 (file)
--- a/src/gui.c
+++ b/src/gui.c
@@ -901,9 +901,10 @@ gui_update_cursor(force, clear_selection)
     int                attr;
     attrentry_T *aep = NULL;
 
-    /* Don't update the cursor when halfway busy scrolling.
-     * ScreenLines[] isn't valid then. */
-    if (!can_update_cursor)
+    /* Don't update the cursor when halfway busy scrolling or the screen size
+     * doesn't match 'columns' and 'lines.  ScreenLines[] isn't valid then. */
+    if (!can_update_cursor || screen_Columns != gui.num_cols
+                                              || screen_Rows != gui.num_rows)
        return;
 
     gui_check_pos();
index 0e703d10c7dd8ccbc383b24dadea18bb64437e5a..77d550fe8097293769167d8cac26000fd7df2f2b 100644 (file)
@@ -676,6 +676,8 @@ static char *(features[]) =
 
 static int included_patches[] =
 {   /* Add new patch number below this line */
+/**/
+    28,
 /**/
     27,
 /**/